# Changelog

## 2.1.1 (2025-01-10)

Full Changelog: [v2.1.0...v2.1.1](https://github.com/evrimai/python-client/compare/v2.1.0...v2.1.1)

### Bug Fixes

* correctly handle deserialising `cls` fields ([#10](https://github.com/evrimai/python-client/issues/10)) ([022ce03](https://github.com/evrimai/python-client/commit/022ce03bbd753d947e8b0bb47216df124cfef0c7))


### Chores

* **internal:** version bump ([#8](https://github.com/evrimai/python-client/issues/8)) ([bc30d36](https://github.com/evrimai/python-client/commit/bc30d368e3a47f4516b0ee1ac5d6d5c9bf0d2747))

## 2.1.0 (2025-01-08)

Full Changelog: [v2.0.0...v2.1.0](https://github.com/evrimai/python-client/compare/v2.0.0...v2.1.0)

### Features

* **api:** update via SDK Studio ([#5](https://github.com/evrimai/python-client/issues/5)) ([768b6fc](https://github.com/evrimai/python-client/commit/768b6fcc9838b5d84b879d0e53663e4f145e729b))
* **api:** update via SDK Studio ([#6](https://github.com/evrimai/python-client/issues/6)) ([27422a5](https://github.com/evrimai/python-client/commit/27422a5b19c7f634b0879f04e35651e6dfd40634))


### Chores

* **internal:** version bump ([#7](https://github.com/evrimai/python-client/issues/7)) ([1b24869](https://github.com/evrimai/python-client/commit/1b24869a016eb23bae79059ecb897297ca551201))
* update SDK settings ([#3](https://github.com/evrimai/python-client/issues/3)) ([3f60f18](https://github.com/evrimai/python-client/commit/3f60f18c14aeaab599a758244796417427b52897))

## 2.0.0 (2025-01-08)

Full Changelog: [v0.0.1-alpha.0...v2.0.0](https://github.com/evrimai/python-client/compare/v0.0.1-alpha.0...v2.0.0)

### Chores

* go live ([#1](https://github.com/evrimai/python-client/issues/1)) ([829c3fb](https://github.com/evrimai/python-client/commit/829c3fb6a9f59d38cea2d0f27893ad30ef1c7938))
